@@ -26,7 +26,7 @@ class KioskData;
 
 class ComponentSelectionPage : public ComponentSelectionPageUI, public PageWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:  
   ComponentSelectionPage( KioskData *data, TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
