@@ -117,7 +117,7 @@ void AutoStartConfig::load() {
             if ( !name.isEmpty() )
             {
                 CheckListItem *clitem = new CheckListItem( _lvStartup, TQString() );
-                connect( clitem, TQT_SIGNAL( changed( TQCheckListItem * ) ), TQT_SLOT( slotItemChecked( TQCheckListItem * ) ) );
+                connect( clitem, TQ_SIGNAL( changed( TQCheckListItem * ) ), TQ_SLOT( slotItemChecked( TQCheckListItem * ) ) );
                 clitem->setText( 1, name );
                 clitem->setText( 2, file.readComment() );
                 clitem->setText( 3, *it );
@@ -150,7 +150,7 @@ void AutoStartConfig::save()
         ++it;
     }
 
-    //TQTimer::singleShot(0, this, TQT_SLOT(slotServiceRunningToggled()));
+    //TQTimer::singleShot(0, this, TQ_SLOT(slotServiceRunningToggled()));
 }
 
 void AutoStartConfig::defaults()
