@@ -778,7 +778,7 @@ KioskRun::setupRuntimeEnv()
    
    tdeinit << "tdeinit";
    
-   connect(&tdeinit, TQT_SIGNAL(processExited(TDEProcess *)), &dlg, TQT_SLOT(slotFinished()));
+   connect(&tdeinit, TQ_SIGNAL(processExited(TDEProcess *)), &dlg, TQ_SLOT(slotFinished()));
    
    tdeinit.start(TDEProcess::NotifyOnExit);
 
@@ -1663,7 +1663,7 @@ KioskRunProgressDialog::KioskRunProgressDialog(TQWidget *parent, const char *nam
                           const TQString &caption, const TQString &text)
  : KProgressDialog(parent, name, caption, text, true)
 {
-  connect(&m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotProgress()));
+  connect(&m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotProgress()));
   progressBar()->setTotalSteps(20);
   m_timeStep = 700;
   m_timer.start(m_timeStep);
@@ -1692,7 +1692,7 @@ KioskRunProgressDialog::slotFinished()
 {
   progressBar()->setProgress(20);
   m_timer.stop();
-  TQTimer::singleShot(1000, this, TQT_SLOT(close()));
+  TQTimer::singleShot(1000, this, TQ_SLOT(close()));
 }
 
 
