@@ -31,7 +31,7 @@ class KSimpleConfig;
 
 class KioskSync : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:  
   KioskSync( TQWidget* parent = 0, const char* name = 0);
